==> buildfile_1.0.0_for_2.1_src.zip: org.vivianj.eclipse.plugin.buildfile/src/org/vivianj/eclipse/plugin/buildfile/wizards/BuildFileDesignerWizard.java <==
/*
 * 2004-10-22 Фݼ 
 */
package org.vivianj.eclipse.plugin.buildfile.wizards;

import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.wizard.Wizard;
import org.eclipse.ui.INewWizard;
import org.eclipse.ui.IWorkbench;
import org.eclipse.core.runtime.*;
import org.eclipse.jface.operation.*;
import java.lang.reflect.InvocationTargetException;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.core.resources.*;
import org.eclipse.core.runtime.CoreException;
import java.io.*;
import org.eclipse.ui.*;

/**
 *BuildFileDesignerWizardṩWizard
 * 
 */

public class BuildFileDesignerWizard extends Wizard implements INewWizard {
	private BuildFileDesignerWizardPage page;
	private ISelection selection;

	/**
	 * BuildFileDesignerWizard
	 */
	public BuildFileDesignerWizard() {
		super();
		setNeedsProgressMonitor(true);
	}

	/**
	 * WizardҪʾ
	 */

	public void addPages() {
		page = new BuildFileDesignerWizardPage(selection);
		addPage(page);
	}

	/**
	 * performFinishWizardеFinish
	 */
	public boolean performFinish() {
		final String containerName = page.getContainerName();
		final String fileName = page.getFileName();
		IRunnableWithProgress op = new IRunnableWithProgress() {
			public void run(IProgressMonitor monitor)
				throws InvocationTargetException {
				try {
					doFinish(containerName, fileName, monitor);
				} catch (CoreException e) {
					throw new InvocationTargetException(e);
				} finally {
					monitor.done();
				}
			}
		};
		try {
			getContainer().run(true, false, op);
		} catch (InterruptedException e) {
			return false;
		} catch (InvocationTargetException e) {
			Throwable realException = e.getTargetException();
			MessageDialog.openError(
				getShell(),
				"Error",
				realException.getMessage());
			return false;
		}
		return true;
	}

	/**
	 * doFinishWizardеFinish
	 */

	private void doFinish(
		String containerName,
		String fileName,
		IProgressMonitor monitor)
		throws CoreException {
		// ģļ
		monitor.beginTask("Creating " + fileName, 2);
		IWorkspaceRoot root = ResourcesPlugin.getWorkspace().getRoot();
		IResource resource = root.findMember(new Path(containerName));
		if (!resource.exists() || !(resource instanceof IContainer)) {
			throwCoreException(
				"Container \"" + containerName + "\" does not exist.");
		}
		IContainer container = (IContainer) resource;
		final IFile file = container.getFile(new Path(fileName));
		try {
			InputStream stream = openContentStream();
			if (file.exists()) {
				file.setContents(stream, true, true, monitor);
			} else {
				file.create(stream, true, monitor);
			}
			stream.close();
		} catch (IOException e) {
		}
		monitor.worked(1);
		monitor.setTaskName("Opening file for editing...");
		getShell().getDisplay().asyncExec(new Runnable() {
			public void run() {

				IWorkbenchPage page =
					PlatformUI
						.getWorkbench()
						.getActiveWorkbenchWindow()
						.getActivePage();
				try {
					page.openEditor(file);
				} catch (PartInitException e) {
				}
			}
		});
		monitor.worked(1);
	}

	/**
	 * ṩģļ
	 */

	private InputStream openContentStream() {
		String contents =
			"<project name=\"new prject\" default=\"init\" basedir=\".\">\r\n  <target name=\"init\">\r\n  </target>\r\n</project>";
		return new ByteArrayInputStream(contents.getBytes());
	}

	private void throwCoreException(String message) throws CoreException {
		IStatus status =
			new Status(
				IStatus.ERROR,
				"JUnitDesigner",
				IStatus.OK,
				message,
				null);
		throw new CoreException(status);
	}

	public void init(IWorkbench workbench, IStructuredSelection selection) {
		this.selection = selection;
	}
}

==> buildfile_1.2.36_for_3.0_src.zip: org.vivianj.eclipse.plugin.buildfile/src/org/vivianj/eclipse/plugin/buildfile/wizards/BuildFileDesignerWizard.java <==
/*
 * 2004-10-21 Фݼ 
 */
package org.vivianj.eclipse.plugin.buildfile.wizards;

import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.wizard.Wizard;
import org.eclipse.ui.INewWizard;
import org.eclipse.ui.IWorkbench;
import org.eclipse.core.runtime.*;
import org.eclipse.jface.operation.*;
import java.lang.reflect.InvocationTargetException;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.core.resources.*;
import org.eclipse.core.runtime.CoreException;
import java.io.*;
import org.eclipse.ui.*;
import org.eclipse.ui.ide.IDE;

/**
 * BuildFileDesignerWizardϵͳעBuildFileDesigner
 */

public class BuildFileDesignerWizard extends Wizard implements INewWizard {
	private BuildFileDesignerWizardPage page;

	private ISelection selection;

	/**
	 * BuildFileDesignerWizard
	 */
	public BuildFileDesignerWizard() {
		super();
		setNeedsProgressMonitor(true);
	}

	/**
	 * ҳ
	 */

	public void addPages() {
		page = new BuildFileDesignerWizardPage(selection);
		addPage(page);
	}

	/**
	 * performFinishʱĶ
	 */
	public boolean performFinish() {
		final String containerName = page.getContainerName();
		final String fileName = page.getFileName();
		IRunnableWithProgress op = new IRunnableWithProgress() {
			public void run(IProgressMonitor monitor)
					throws InvocationTargetException {
				try {
					doFinish(containerName, fileName, monitor);
				} catch (CoreException e) {
					throw new InvocationTargetException(e);
				} finally {
					monitor.done();
				}
			}
		};
		try {
			getContainer().run(true, false, op);
		} catch (InterruptedException e) {
			return false;
		} catch (InvocationTargetException e) {
			Throwable realException = e.getTargetException();
			MessageDialog.openError(getShell(), "Error", realException
					.getMessage());
			return false;
		}
		return true;
	}

	/**
	 * doFinishFinishťʵʴ
	 */

	private void doFinish(String containerName, String fileName,
			IProgressMonitor monitor) throws CoreException {
		// ģ
		monitor.beginTask("Creating " + fileName, 2);
		IWorkspaceRoot root = ResourcesPlugin.getWorkspace().getRoot();
		IResource resource = root.findMember(new Path(containerName));
		if (!resource.exists() || !(resource instanceof IContainer)) {
			throwCoreException("Container \"" + containerName
					+ "\" does not exist.");
		}
		IContainer container = (IContainer) resource;
		final IFile file = container.getFile(new Path(fileName));
		try {
			InputStream stream = openContentStream();
			if (file.exists()) {
				file.setContents(stream, true, true, monitor);
			} else {
				file.create(stream, true, monitor);
			}
			stream.close();
		} catch (IOException e) {
		}
		monitor.worked(1);
		monitor.setTaskName("Opening file for editing...");
		getShell().getDisplay().asyncExec(new Runnable() {
			public void run() {
				IWorkbenchPage page = PlatformUI.getWorkbench()
						.getActiveWorkbenchWindow().getActivePage();
				try {
					IDE.openEditor(page, file, true);
				} catch (PartInitException e) {
				}
			}
		});
		monitor.worked(1);
	}

	/**
	 * Ĭϵbuildfile
	 */

	private InputStream openContentStream() {
		String contents = "<project name=\"new prject\" default=\"init\" basedir=\".\">\r\n  <target name=\"init\">\r\n  </target>\r\n</project>";
		return new ByteArrayInputStream(contents.getBytes());
	}

	private void throwCoreException(String message) throws CoreException {
		IStatus status = new Status(IStatus.ERROR, "BuildFileDesigner",
				IStatus.OK, message, null);
		throw new CoreException(status);
	}

	public void init(IWorkbench workbench, IStructuredSelection selection) {
		this.selection = selection;
	}
}
